SYD(5)

# NAME

syd - document format for writing syd profiles

# API

Current version of the syd command API is *3*. This version is *stable*.

# CONFIGURATION

syd is configured through sandbox commands. For multiple matching rules (e.g.
two rules matching the same path), _the last matching rule wins_. There are two
ways to supply sandbox commands. First, syd may be configured using a
configuration file. The path to the configuration file is speficied using the
*-P* command line switch. More than one configuration file may be specified this
way. Single commands may also be passed via *-m* command line switch.
Configuration profiles may be applied using the *-p* command line switch. See
*PROFILES* section for more information. Second, syd may be configured using
*magic* _stat_(2) calls during runtime.  This is achieved by calling _stat_(2)
system call on the special path */dev/syd* followed by the sandbox command. Note
that runtime configuration is only possible if the sandbox lock is *unset*. The
system call _stat_(2) was chosen because it is practical to invoke using builtin
shell commands like:

```
; test -c /dev/syd/sandbox/read:on
```

which enables *Read Sandboxing* for a shell running under syd. It is
also possible to query certain values using the return value of the
_stat_(2) call:

```
test -c /dev/syd/sandbox/read? && echo read sandboxing on || echo read sandboxing off
```

Note, some of these shell builtins may actually call other system calls such as
_fstat_(2), _lstat_(2), _newfstatat_(2), or _statx_(2). syd supports the same
interface through all these system calls transparently. Check the manual page
_syd_(2) for a description of the _stat_(2) interface.

# SYNTAX

Input files must use the UTF-8 encoding. Format is simple. It is just a way to
supply many sandbox commands in a convenient way. All empty lines and lines
starting with the sign *#* are ignored. All the other lines are treated as if
they were supplied to syd via the *-m* command line switch. For a list of
available sandbox commands, consult _syd_(2).

# NAMING

Configuration file naming of syd follows a naming scheme which makes it
possible to extract command API version from the file name. A syd
configuration file must have the extension *syd-* followed by the API version
(e.g. *"syd-3"* for API version *3*).

# EXAMPLE

```
# syd profile for OpenNTPD

# Seccomp sandbox
sandbox/read:on
sandbox/stat:on
sandbox/write:on
sandbox/exec:on
sandbox/net:on

# Landlock
sandbox/lock:on

# Provide isolation using namespaces.
unshare/mount:1
unshare/uts:1
unshare/pid:1
unshare/ipc:1
unshare/cgroup:1

# Allow adjtimex and keep CAP_SYS_TIME.
trace/allow_unsafe_adjtime:1

# Mount everything ro except /var
trace/private_shm:1
trace/private_tmp:1
bind+/etc:/etc:ro,nodev,noexec,nosuid,noatime
bind+/home:/home:ro,nodev,noexec,nosuid,noatime
bind+/media:/media:ro,nodev,noexec,nosuid,noatime
bind+/mnt:/mnt:ro,nodev,noexec,nosuid,noatime
bind+/opt:/opt:ro,nodev,nosuid,noatime
bind+/srv:/srv:ro,nodev,noexec,nosuid,noatime
bind+/usr:/usr:ro,nodev,noatime

# Hide syd
deny/read,stat,write+/proc/1/***

# Allow listen to the ntp port on loopback.
allow/net/bind+loopback!123

# Allow connections to NTP servers.
allow/net/connect+any!53
allow/net/connect+any!123
allow/net/connect+any!65535

# Allow logging to syslog.
allow/net/connect+/dev/log

# Allow `listen wildcard`
allow/net/bind+0.0.0.0!0
allow/net/connect+0.0.0.0!0

# Allow listen to the ntpd socket.
allow/net/bind+/run/ntpd.sock
allow/net/bind+/var/run/ntpd.sock
allow/write+/run/ntpd.sock
allow/write+/var/run/ntpd.sock

# Allow access to system paths
allow/read,stat+/dev/urandom
allow/lock/read+/dev/urandom
allow/read,stat+/etc/hosts
allow/lock/read+/etc/hosts
allow/read,stat+/etc/ntpd.conf
allow/lock/read+/etc/ntpd.conf
allow/read,stat+/etc/passwd
allow/lock/read+/etc/passwd
allow/read,stat+/etc/resolv.conf
allow/lock/read+/etc/resolv.conf
allow/read,stat+/etc/services
allow/lock/read+/etc/services
allow/read,stat+/usr/share/zoneinfo-posix/UTC

# chroot /var/empty && cd /
allow/stat+/
allow/stat+/var/empty
allow/write+/dev/null
allow/lock/write+/dev/null

# Allow executing the ntp binary.
allow/lock/read+/proc
allow/lock/read+/usr
allow/lock/write+/run
allow/lock/write+/var/run
allow/exec+/usr/**/bin/openntpd*

# Allow writing the drift file.
allow/write+/var/db/ntpd.drift
allow/lock/write+/var/db/ntpd.drift

# Lock configuration
lock:on
```

# SEE ALSO

_syd_(1), _syd_(2), _syd_(7)

*syd* homepage: https://sydbox.exherbolinux.org/

# AUTHORS

Maintained by Ali Polatel. Up-to-date sources can be found at
https://git.sr.ht/~alip/syd and bugs/patches can be submitted by email to
~alip/sydbox-devel@lists.sr.ht. Exherbo related bugs/issues can be submitted to
https://gitlab.exherbo.org/groups/sydbox/-/issues.
